marktools.BarLine
=================

.. abjad-lineage:: abjad.tools.marktools.BarLine.BarLine.BarLine

.. autoclass:: abjad.tools.marktools.BarLine.BarLine.BarLine
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.bar_line_string
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.command_name
   :noindex:

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.format_slot
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.attach
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__repr__
   :noindex:
